@@ -35,7 +35,8 @@ class Proxy(_base_proxy.BaseImageProxy):
         """
         return self._create(_image.Image, **kwargs)
 
-    def import_image(self, image, method='glance-direct', uri=None):
+    def import_image(self, image, method='glance-direct', uri=None,
+                     store=None):
         """Import data to an existing image
 
         Interoperable image import process are introduced in the Image API
@@ -50,10 +51,16 @@ class Proxy(_base_proxy.BaseImageProxy):
         :param uri: Required only if using the web-download import method.
                     This url is where the data is made available to the Image
                     service.
+        :param store: Used when enabled_backends is activated in glance
+                      The value can be the id of a store or a
+                      :class:`~openstack.image.v2.service_info.Store`
+                      instance.
 
         :returns: None
         """
         image = self._get_resource(_image.Image, image)
+        if store is not None:
+            store = self._get_resource(_si.Store, store)
 
         # as for the standard image upload function, container_format and
         # disk_format are required for using image import process
@@ -62,7 +69,37 @@ class Proxy(_base_proxy.BaseImageProxy):
                 "Both container_format and disk_format are required for"
                 " importing an image")
 
-        image.import_image(self, method=method, uri=uri)
+        image.import_image(self, method=method, uri=uri, store=store)
+
+    def stage_image(self, image, filename=None, data=None):
+        """Stage binary image data
+
+        :param image: The value can be the ID of a image or a
+            :class:`~openstack.image.v2.image.Image` instance.
+        :param filename: Optional name of the file to read data from.
+        :param data: Optional data to be uploaded as an image.
+
+        :returns: The results of image creation
+        :rtype: :class:`~openstack.image.v2.image.Image`
+        """
+        image = self._get_resource(_image.Image, image)
+
+        if 'queued' != image.status:
+            raise exceptions.SDKException('Image stage is only possible for '
+                                          'images in the queued state.'
+                                          ' Current state is {status}'
+                                          .format(status=image.status))
+
+        if filename:
+            image.data = open(filename, 'rb')
+        elif data:
+            image.data = data
+        image.stage(self)
+
+        # Stage does not return content, but updates the object
+        image.fetch(self)
+
+        return image
 
     def upload_image(self, container_format=None, disk_format=None,
                      data=None, **attrs):
@@ -214,7 +251,8 @@ class Proxy(_base_proxy.BaseImageProxy):
             container, name, filename,
             md5=md5, sha256=sha256,
             metadata={self._connection._OBJECT_AUTOCREATE_KEY: 'true'},
-            **{'content-type': 'application/octet-stream'})
+            **{'content-type': 'application/octet-stream',
+               'x-delete-after': str(24 * 60 * 60)})
         # TODO(mordred): Can we do something similar to what nodepool does
         # using glance properties to not delete then upload but instead make a
         # new "good" image and then mark the old one as "bad"
