@@ -9,17 +9,13 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
-import hashlib
-import io
-import six
-
 from openstack import exceptions
+from openstack.image import _download
 from openstack import resource
 from openstack import utils
 
 
-class Image(resource.Resource, resource.TagMixin):
+class Image(resource.Resource, resource.TagMixin, _download.DownloadMixin):
     resources_key = 'images'
     base_path = '/images'
 
@@ -262,72 +258,33 @@ class Image(resource.Resource, resource.TagMixin):
                            headers={"Content-Type": "application/octet-stream",
                                     "Accept": ""})
 
-    def import_image(self, session, method='glance-direct', uri=None):
+    def stage(self, session):
+        """Stage binary image data into an existing image"""
+        url = utils.urljoin(self.base_path, self.id, 'stage')
+        response = session.put(
+            url, data=self.data,
+            headers={"Content-Type": "application/octet-stream",
+                     "Accept": ""})
+        self._translate_response(response, has_body=False)
+        return self
+
+    def import_image(self, session, method='glance-direct', uri=None,
+                     store=None):
         """Import Image via interoperable image import process"""
         url = utils.urljoin(self.base_path, self.id, 'import')
         json = {'method': {'name': method}}
         if uri:
             if method == 'web-download':
                 json['method']['uri'] = uri
+            elif method == 'glance-direct':
+                json['method']['uri'] = uri
             else:
                 raise exceptions.InvalidRequest('URI is only supported with '
                                                 'method: "web-download"')
-        session.post(url, json=json)
-
-    def download(self, session, stream=False, output=None, chunk_size=1024):
-        """Download the data contained in an image"""
-        # TODO(briancurtin): This method should probably offload the get
-        # operation into another thread or something of that nature.
-        url = utils.urljoin(self.base_path, self.id, 'file')
-        resp = session.get(url, stream=stream)
-
-        # See the following bug report for details on why the checksum
-        # code may sometimes depend on a second GET call.
-        # https://storyboard.openstack.org/#!/story/1619675
-        checksum = resp.headers.get('Content-MD5')
-
-        if checksum is None:
-            # If we don't receive the Content-MD5 header with the download,
-            # make an additional call to get the image details and look at
-            # the checksum attribute.
-            details = self.fetch(session)
-            checksum = details.checksum
-
-        if output:
-            try:
-                # In python 2 we might get StringIO - delete it as soon as
-                # py2 support is dropped
-                if isinstance(output, io.IOBase) \
-                        or isinstance(output, six.StringIO):
-                    for chunk in resp.iter_content(chunk_size=chunk_size):
-                        output.write(chunk)
-                else:
-                    with open(output, 'wb') as fd:
-                        for chunk in resp.iter_content(
-                                chunk_size=chunk_size):
-                            fd.write(chunk)
-                return resp
-            except Exception as e:
-                raise exceptions.SDKException(
-                    'Unable to download image: %s' % e)
-        # if we are returning the repsonse object, ensure that it
-        # has the content-md5 header so that the caller doesn't
-        # need to jump through the same hoops through which we
-        # just jumped.
-        if stream:
-            resp.headers['content-md5'] = checksum
-            return resp
-
-        if checksum is not None:
-            digest = hashlib.md5(resp.content).hexdigest()
-            if digest != checksum:
-                raise exceptions.InvalidResponse(
-                    "checksum mismatch: %s != %s" % (checksum, digest))
-        else:
-            session.log.warn(
-                "Unable to verify the integrity of image %s" % (self.id))
-
-        return resp
+        headers = {}
+        if store is not None:
+            headers = {'X-Image-Meta-Store': store.id}
+        session.post(url, json=json, headers=headers)
 
     def _prepare_request(self, requires_id=None, prepend_key=False,
                          patch=False, base_path=None):
