@@ -10,6 +10,9 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+from openstack.load_balancer.v2 import amphora as _amphora
+from openstack.load_balancer.v2 import flavor as _flavor
+from openstack.load_balancer.v2 import flavor_profile as _flavor_profile
 from openstack.load_balancer.v2 import health_monitor as _hm
 from openstack.load_balancer.v2 import l7_policy as _l7policy
 from openstack.load_balancer.v2 import l7_rule as _l7rule
@@ -17,6 +20,8 @@ from openstack.load_balancer.v2 import listener as _listener
 from openstack.load_balancer.v2 import load_balancer as _lb
 from openstack.load_balancer.v2 import member as _member
 from openstack.load_balancer.v2 import pool as _pool
+from openstack.load_balancer.v2 import provider as _provider
+from openstack.load_balancer.v2 import quota as _quota
 from openstack import proxy
 from openstack import resource
 
@@ -49,12 +54,23 @@ class Proxy(proxy.Proxy):
         """
         return self._get(_lb.LoadBalancer, *attrs)
 
+    def get_load_balancer_statistics(self, name_or_id):
+        """Get the load balancer statistics
+
+        :param name_or_id: The name or ID of a load balancer
+
+        :returns: One :class:`~openstack.load_balancer.v2.load_balancer.
+                  LoadBalancerStats`
+        """
+        return self._get(_lb.LoadBalancerStats, lb_id=name_or_id,
+                         requires_id=False)
+
     def load_balancers(self, **query):
         """Retrieve a generator of load balancers
 
         :returns: A generator of load balancer instances
         """
-        return self._list(_lb.LoadBalancer, paginated=True, **query)
+        return self._list(_lb.LoadBalancer, **query)
 
     def delete_load_balancer(self, load_balancer, ignore_missing=True,
                              cascade=False):
@@ -114,6 +130,15 @@ class Proxy(proxy.Proxy):
         return resource.wait_for_status(self, lb, status, failures, interval,
                                         wait, attribute='provisioning_status')
 
+    def failover_load_balancer(self, name_or_id, **attrs):
+        """Failover a load balancer
+
+        :param name_or_id: The name or ID of a load balancer
+
+        :returns: ``None``
+        """
+        return self._update(_lb.LoadBalancerFailover, lb_id=name_or_id)
+
     def create_listener(self, **attrs):
         """Create a new listener from attributes
 
@@ -171,6 +196,21 @@ class Proxy(proxy.Proxy):
         """
         return self._get(_listener.Listener, listener)
 
+    def get_listener_statistics(self, listener):
+        """Get the listener statistics
+
+        :param listener: The value can be the ID of a listener or a
+               :class:`~openstack.load_balancer.v2.listener.Listener`
+               instance.
+
+        :returns: One :class:`~openstack.load_balancer.v2.listener.
+            ListenerStats`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+                 when no resource can be found.
+        """
+        return self._get(_listener.ListenerStats, listener_id=listener,
+                         requires_id=False)
+
     def listeners(self, **query):
         """Return a generator of listeners
 
@@ -179,7 +219,7 @@ class Proxy(proxy.Proxy):
         :returns: A generator of listener objects
         :rtype: :class:`~openstack.load_balancer.v2.listener.Listener`
         """
-        return self._list(_listener.Listener, paginated=True, **query)
+        return self._list(_listener.Listener, **query)
 
     def update_listener(self, listener, **attrs):
         """Update a listener
@@ -226,7 +266,7 @@ class Proxy(proxy.Proxy):
 
         :returns: A generator of Pool instances
         """
-        return self._list(_pool.Pool, paginated=True, **query)
+        return self._list(_pool.Pool, **query)
 
     def delete_pool(self, pool, ignore_missing=True):
         """Delete a pool
@@ -363,8 +403,7 @@ class Proxy(proxy.Proxy):
         :rtype: :class:`~openstack.load_balancer.v2.member.Member`
         """
         poolobj = self._get_resource(_pool.Pool, pool)
-        return self._list(_member.Member, paginated=True,
-                          pool_id=poolobj.id, **query)
+        return self._list(_member.Member, pool_id=poolobj.id, **query)
 
     def update_member(self, member, pool, **attrs):
         """Update a member
@@ -450,7 +489,7 @@ class Proxy(proxy.Proxy):
 
         :returns: A generator of health monitor instances
         """
-        return self._list(_hm.HealthMonitor, paginated=True, **query)
+        return self._list(_hm.HealthMonitor, **query)
 
     def delete_health_monitor(self, healthmonitor, ignore_missing=True):
         """Delete a health monitor
@@ -553,7 +592,7 @@ class Proxy(proxy.Proxy):
         :returns: A generator of l7policy objects
         :rtype: :class:`~openstack.load_balancer.v2.l7_policy.L7Policy`
         """
-        return self._list(_l7policy.L7Policy, paginated=True, **query)
+        return self._list(_l7policy.L7Policy, **query)
 
     def update_l7_policy(self, l7_policy, **attrs):
         """Update a l7policy
@@ -659,8 +698,7 @@ class Proxy(proxy.Proxy):
         :rtype: :class:`~openstack.load_balancer.v2.l7_rule.L7Rule`
         """
         l7policyobj = self._get_resource(_l7policy.L7Policy, l7_policy)
-        return self._list(_l7rule.L7Rule, paginated=True,
-                          l7policy_id=l7policyobj.id, **query)
+        return self._list(_l7rule.L7Rule, l7policy_id=l7policyobj.id, **query)
 
     def update_l7_rule(self, l7rule, l7_policy, **attrs):
         """Update a l7rule
@@ -680,3 +718,290 @@ class Proxy(proxy.Proxy):
         l7policyobj = self._get_resource(_l7policy.L7Policy, l7_policy)
         return self._update(_l7rule.L7Rule, l7rule,
                             l7policy_id=l7policyobj.id, **attrs)
+
+    def quotas(self, **query):
+        """Return a generator of quotas
+
+        :param dict query: Optional query parameters to be sent to limit
+                           the resources being returned. Currently no query
+                           parameter is supported.
+
+        :returns: A generator of quota objects
+        :rtype: :class:`~openstack.load_balancer.v2.quota.Quota`
+        """
+        return self._list(_quota.Quota, **query)
+
+    def get_quota(self, quota):
+        """Get a quota
+
+        :param quota: The value can be the ID of a quota or a
+                      :class:`~openstack.load_balancer.v2.quota.Quota`
+                      instance. The ID of a quota is the same as the project
+                      ID for the quota.
+
+        :returns: One :class:`~openstack.load_balancer.v2.quota.Quota`
+        :raises: :class:`~openstack.exceptions.ResourceNotFound`
+                 when no resource can be found.
+        """
+        return self._get(_quota.Quota, quota)
+
+    def update_quota(self, quota, **attrs):
+        """Update a quota
+
+        :param quota: Either the ID of a quota or a
+                      :class:`~openstack.load_balancer.v2.quota.Quota`
+                      instance. The ID of a quota is the same as the
+                      project ID for the quota.
+        :param dict attrs: The attributes to update on the quota represented
+                           by ``quota``.
+
+        :returns: The updated quota
+        :rtype: :class:`~openstack.load_balancer.v2.quota.Quota`
+        """
+        return self._update(_quota.Quota, quota, **attrs)
+
+    def get_quota_default(self):
+        """Get a default quota
+
+        :returns: One :class:`~openstack.load_balancer.v2.quota.QuotaDefault`
+        """
+        return self._get(_quota.QuotaDefault, requires_id=False)
+
+    def delete_quota(self, quota, ignore_missing=True):
+        """Delete a quota (i.e. reset to the default quota)
+
+        :param quota: The value can be either the ID of a quota or a
+                      :class:`~openstack.load_balancer.v2.quota.Quota`
+                      instance. The ID of a quota is the same as the
+                      project ID for the quota.
+        :param bool ignore_missing: When set to ``False``
+                    :class:`~openstack.exceptions.ResourceNotFound` will be
+                    raised when quota does not exist.
+                    When set to ``True``, no exception will be set when
+                    attempting to delete a nonexistent quota.
+
+        :returns: ``None``
+        """
+        self._delete(_quota.Quota, quota, ignore_missing=ignore_missing)
+
+    def providers(self, **query):
+        """Retrieve a generator of providers
+
+        :returns: A generator of providers instances
+        """
+        return self._list(_provider.Provider, **query)
+
+    def provider_flavor_capabilities(self, provider, **query):
+        """Retrieve a generator of provider flavor capabilities
+
+        :returns: A generator of provider flavor capabilities instances
+        """
+        return self._list(_provider.ProviderFlavorCapabilities,
+                          provider=provider, **query)
+
+    def create_flavor_profile(self, **attrs):
+        """Create a new flavor profile from attributes
+
+        :param dict attrs: Keyword arguments which will be used to create
+                           a :class:`~openstack.load_balancer.v2.
+                           flavor_profile.FlavorProfile`,
+                           comprised of the properties on the
+                           FlavorProfile class.
+
+        :returns: The results of profile creation creation
+        :rtype: :class:`~openstack.load_balancer.v2.flavor_profile.
+                        FlavorProfile`
+        """
+        return self._create(_flavor_profile.FlavorProfile, **attrs)
+
+    def get_flavor_profile(self, *attrs):
+        """Get a flavor profile
+
+        :param flavor_profile: The value can be the name of a flavor profile
+             or :class:`~openstack.load_balancer.v2.flavor_profile.
+             FlavorProfile` instance.
+
+        :returns: One
+             :class:`~openstack.load_balancer.v2.flavor_profile.FlavorProfile`
+        """
+        return self._get(_flavor_profile.FlavorProfile, *attrs)
+
+    def flavor_profiles(self, **query):
+        """Retrieve a generator of flavor profiles
+
+        :returns: A generator of flavor profiles instances
+        """
+        return self._list(_flavor_profile.FlavorProfile, **query)
+
+    def delete_flavor_profile(self, flavor_profile, ignore_missing=True):
+        """Delete a flavor profile
+
+        :param flavor_profile: The flavor_profile can be either the name or a
+            :class:`~openstack.load_balancer.v2.flavor_profile.FlavorProfile`
+            instance
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the flavor profile does not exist.
+            When set to ``True``, no exception will be set when attempting to
+            delete a nonexistent flavor profile.
+
+        :returns: ``None``
+        """
+        self._delete(_flavor_profile.FlavorProfile, flavor_profile,
+                     ignore_missing=ignore_missing)
+
+    def find_flavor_profile(self, name_or_id, ignore_missing=True):
+        """Find a single flavor profile
+
+        :param name_or_id: The name or ID of a flavor profile
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised
+            when the flavor profile does not exist.
+            When set to ``True``, no exception will be set when attempting
+            to delete a nonexistent flavor profile.
+
+        :returns: ``None``
+        """
+        return self._find(_flavor_profile.FlavorProfile, name_or_id,
+                          ignore_missing=ignore_missing)
+
+    def update_flavor_profile(self, flavor_profile, **attrs):
+        """Update a flavor profile
+
+        :param flavor_profile: The flavor_profile can be either the name or a
+            :class:`~openstack.load_balancer.v2.flavor_profile.FlavorProfile`
+            instance
+        :param dict attrs: The attributes to update on the flavor profile
+                           represented by ``flavor_profile``.
+
+        :returns: The updated flavor profile
+        :rtype: :class:`~openstack.load_balancer.v2.flavor_profile.
+                        FlavorProfile`
+        """
+        return self._update(_flavor_profile.FlavorProfile, flavor_profile,
+                            **attrs)
+
+    def create_flavor(self, **attrs):
+        """Create a new flavor from attributes
+
+        :param dict attrs: Keyword arguments which will be used to create
+                           a :class:`~openstack.load_balancer.v2.
+                           flavor.Flavor`, comprised of the properties on the
+                           Flavorclass.
+
+        :returns: The results of flavor creation creation
+        :rtype: :class:`~openstack.load_balancer.v2.flavor.Flavor`
+        """
+        return self._create(_flavor.Flavor, **attrs)
+
+    def get_flavor(self, *attrs):
+        """Get a flavor
+
+        :param flavor: The value can be the name of a flavor
+             or :class:`~openstack.load_balancer.v2.flavor.Flavor` instance.
+
+        :returns: One
+             :class:`~openstack.load_balancer.v2.flavor.Flavor`
+        """
+        return self._get(_flavor.Flavor, *attrs)
+
+    def flavors(self, **query):
+        """Retrieve a generator of flavors
+
+        :returns: A generator of flavor instances
+        """
+        return self._list(_flavor.Flavor, **query)
+
+    def delete_flavor(self, flavor, ignore_missing=True):
+        """Delete a flavor
+
+        :param flavor: The flavorcan be either the name or a
+            :class:`~openstack.load_balancer.v2.flavor.Flavor` instance
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised when
+            the flavor does not exist.
+            When set to ``True``, no exception will be set when attempting to
+            delete a nonexistent flavor.
+
+        :returns: ``None``
+        """
+        self._delete(_flavor.Flavor, flavor, ignore_missing=ignore_missing)
+
+    def find_flavor(self, name_or_id, ignore_missing=True):
+        """Find a single flavor
+
+        :param name_or_id: The name or ID of a flavor
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised
+            when the flavor does not exist.
+            When set to ``True``, no exception will be set when attempting
+            to delete a nonexistent flavor.
+
+        :returns: ``None``
+        """
+        return self._find(_flavor.Flavor, name_or_id,
+                          ignore_missing=ignore_missing)
+
+    def update_flavor(self, flavor, **attrs):
+        """Update a flavor
+
+        :param flavor: The flavor can be either the name or a
+            :class:`~openstack.load_balancer.v2.flavor.Flavor` instance
+        :param dict attrs: The attributes to update on the flavor
+                           represented by ``flavor``.
+
+        :returns: The updated flavor
+        :rtype: :class:`~openstack.load_balancer.v2.flavor.Flavor`
+        """
+        return self._update(_flavor.Flavor, flavor, **attrs)
+
+    def amphorae(self, **query):
+        """Retrieve a generator of amphorae
+
+        :returns: A generator of amphora instances
+        """
+        return self._list(_amphora.Amphora, **query)
+
+    def get_amphora(self, *attrs):
+        """Get a amphora
+
+        :param amphora: The value can be the ID of an amphora
+             or :class:`~openstack.load_balancer.v2.amphora.Amphora` instance.
+
+        :returns: One
+             :class:`~openstack.load_balancer.v2.amphora.Amphora`
+        """
+        return self._get(_amphora.Amphora, *attrs)
+
+    def find_amphora(self, amphora_id, ignore_missing=True):
+        """Find a single amphora
+
+        :param amphora_id: The ID of a amphora
+        :param bool ignore_missing: When set to ``False``
+            :class:`~openstack.exceptions.ResourceNotFound` will be raised
+            when the amphora does not exist.
+            When set to ``True``, no exception will be set when attempting
+            to find a nonexistent amphora.
+
+        :returns: ``None``
+        """
+        return self._find(_amphora.Amphora, amphora_id,
+                          ignore_missing=ignore_missing)
+
+    def configure_amphora(self, amphora_id, **attrs):
+        """Update the configuration of an amphora agent
+
+        :param amphora_id: The ID of an amphora
+
+        :returns: ``None``
+        """
+        return self._update(_amphora.AmphoraConfig, amphora_id=amphora_id)
+
+    def failover_amphora(self, amphora_id, **attrs):
+        """Failover an amphora
+
+        :param amphora_id: The ID of an amphora
+
+        :returns: ``None``
+        """
+        return self._update(_amphora.AmphoraFailover, amphora_id=amphora_id)
