@@ -17,6 +17,7 @@ import os_service_types
 
 from openstack import _log
 from openstack import exceptions
+from openstack import proxy as proxy_mod
 
 __all__ = [
     'ServiceDescription',
@@ -26,6 +27,18 @@ _logger = _log.setup_logging('openstack')
 _service_type_manager = os_service_types.ServiceTypes()
 
 
+class _ServiceDisabledProxyShim(object):
+    def __init__(self, service_type, reason):
+        self.service_type = service_type
+        self.reason = reason
+
+    def __getattr__(self, item):
+        raise exceptions.ServiceDisabledException(
+            "Service '{service_type}' is disabled because its configuration "
+            "could not be loaded. {reason}".format(
+                service_type=self.service_type, reason=self.reason or ''))
+
+
 class ServiceDescription(object):
 
     #: Dictionary of supported versions and proxy classes for that version
@@ -71,10 +84,34 @@ class ServiceDescription(object):
         if instance is None:
             return self
         if self.service_type not in instance._proxies:
-            instance._proxies[self.service_type] = self._make_proxy(instance)
-            instance._proxies[self.service_type]._connection = instance
+            proxy = self._make_proxy(instance)
+            if not isinstance(proxy, _ServiceDisabledProxyShim):
+                # The keystone proxy has a method called get_endpoint
+                # that is about managing keystone endpoints. This is
+                # unfortunate.
+                endpoint = proxy_mod.Proxy.get_endpoint(proxy)
+                if instance._strict_proxies:
+                    self._validate_proxy(proxy, endpoint)
+                proxy._connection = instance
+            instance._proxies[self.service_type] = proxy
         return instance._proxies[self.service_type]
 
+    def _validate_proxy(self, proxy, endpoint):
+        exc = None
+        service_url = getattr(proxy, 'skip_discovery', None)
+        try:
+            # Don't go too wild for e.g. swift
+            if service_url is None:
+                service_url = proxy.get_endpoint_data().service_url
+        except Exception as e:
+            exc = e
+        if exc or not endpoint or not service_url:
+            raise exceptions.ServiceDiscoveryException(
+                "Failed to create a working proxy for service {service_type}: "
+                "{message}".format(
+                    service_type=self.service_type,
+                    message=exc or "No valid endpoint was discoverable."))
+
     def _make_proxy(self, instance):
         """Create a Proxy for the service in question.
 
@@ -83,7 +120,22 @@ class ServiceDescription(object):
         """
         config = instance.config
 
-        # First, check to see if we've got config that matches what we
+        if not config.has_service(self.service_type):
+            return _ServiceDisabledProxyShim(
+                self.service_type,
+                config.get_disabled_reason(self.service_type))
+
+        # We don't know anything about this service, so the user is
+        # explicitly just using us for a passthrough REST adapter.
+        # Skip all the lower logic.
+        if not self.supported_versions:
+            temp_client = config.get_session_client(
+                self.service_type,
+                allow_version_hack=True,
+            )
+            return temp_client
+
+        # Check to see if we've got config that matches what we
         # understand in the SDK.
         version_string = config.get_api_version(self.service_type)
         endpoint_override = config.get_endpoint(self.service_type)
@@ -94,7 +146,7 @@ class ServiceDescription(object):
             version_string = list(self.supported_versions)[0]
 
         proxy_obj = None
-        if endpoint_override and version_string and self.supported_versions:
+        if endpoint_override and version_string:
             # Both endpoint override and version_string are set, we don't
             # need to do discovery - just trust the user.
             proxy_class = self.supported_versions.get(version_string[0])
@@ -112,7 +164,7 @@ class ServiceDescription(object):
                         version=version_string,
                         service_type=self.service_type),
                     category=exceptions.UnsupportedServiceVersion)
-        elif endpoint_override and self.supported_versions:
+        elif endpoint_override:
             temp_adapter = config.get_session_client(
                 self.service_type
             )
@@ -144,6 +196,12 @@ class ServiceDescription(object):
                 return proxy_obj
 
             data = proxy_obj.get_endpoint_data()
+            if not data and instance._strict_proxies:
+                raise exceptions.ServiceDiscoveryException(
+                    "Failed to create a working proxy for service "
+                    "{service_type}: No endpoint data found.".format(
+                        service_type=self.service_type))
+
             # If we've gotten here with a proxy object it means we have
             # an endpoint_override in place. If the catalog_url and
             # service_url don't match, which can happen if there is a
@@ -152,7 +210,7 @@ class ServiceDescription(object):
             # so that subsequent discovery calls don't get made incorrectly.
             if data.catalog_url != data.service_url:
                 ep_key = '{service_type}_endpoint_override'.format(
-                    service_type=self.service_type)
+                    service_type=self.service_type.replace('-', '_'))
                 config.config[ep_key] = data.service_url
                 proxy_obj = config.get_session_client(
                     self.service_type,
@@ -164,7 +222,7 @@ class ServiceDescription(object):
         version_kwargs = {}
         if version_string:
             version_kwargs['version'] = version_string
-        elif self.supported_versions:
+        else:
             supported_versions = sorted([
                 int(f) for f in self.supported_versions])
             version_kwargs['min_version'] = str(supported_versions[0])
@@ -178,41 +236,42 @@ class ServiceDescription(object):
         )
         found_version = temp_adapter.get_api_major_version()
         if found_version is None:
+            region_name = instance.config.get_region_name(self.service_type)
             if version_kwargs:
                 raise exceptions.NotSupported(
                     "The {service_type} service for {cloud}:{region_name}"
                     " exists but does not have any supported versions.".format(
                         service_type=self.service_type,
                         cloud=instance.name,
-                        region_name=instance.config.region_name))
+                        region_name=region_name))
             else:
                 raise exceptions.NotSupported(
                     "The {service_type} service for {cloud}:{region_name}"
                     " exists but no version was discoverable.".format(
                         service_type=self.service_type,
                         cloud=instance.name,
-                        region_name=instance.config.region_name))
-        proxy_class = self.supported_versions.get(str(found_version[0]))
-        if not proxy_class:
-            # Maybe openstacksdk is being used for the passthrough
-            # REST API proxy layer for an unknown service in the
-            # service catalog that also doesn't have any useful
-            # version discovery?
-            warnings.warn(
-                "Service {service_type} has no discoverable version."
-                " The resulting Proxy object will only have direct"
-                " passthrough REST capabilities.".format(
-                    service_type=self.service_type),
-                category=exceptions.UnsupportedServiceVersion)
-            return temp_adapter
+                        region_name=region_name))
         proxy_class = self.supported_versions.get(str(found_version[0]))
         if proxy_class:
-            version_kwargs['constructor'] = proxy_class
-        return config.get_session_client(
-            self.service_type,
-            allow_version_hack=True,
-            **version_kwargs
-        )
+            return config.get_session_client(
+                self.service_type,
+                allow_version_hack=True,
+                constructor=proxy_class,
+                **version_kwargs
+            )
+
+        # No proxy_class
+        # Maybe openstacksdk is being used for the passthrough
+        # REST API proxy layer for an unknown service in the
+        # service catalog that also doesn't have any useful
+        # version discovery?
+        warnings.warn(
+            "Service {service_type} has no discoverable version."
+            " The resulting Proxy object will only have direct"
+            " passthrough REST capabilities.".format(
+                service_type=self.service_type),
+            category=exceptions.UnsupportedServiceVersion)
+        return temp_adapter
 
     def __set__(self, instance, value):
         raise AttributeError('Service Descriptors cannot be set')
