@@ -19,6 +19,7 @@ Fakes used for testing
 
 import datetime
 import json
+import hashlib
 import uuid
 
 from openstack.orchestration.util import template_format
@@ -158,7 +159,7 @@ def make_fake_server(
 
 def make_fake_keypair(name):
     # Note: this is literally taken from:
-    # https://developer.openstack.org/api-ref/compute/
+    # https://docs.openstack.org/api-ref/compute/
     return {
         "fingerprint": "7e:eb:ab:24:ba:d1:e1:88:ae:9a:fb:66:53:df:d3:bd",
         "name": name,
@@ -220,7 +221,18 @@ def make_fake_stack_event(
 
 def make_fake_image(
         image_id=None, md5=NO_MD5, sha256=NO_SHA256, status='active',
-        image_name=u'fake_image'):
+        image_name=u'fake_image',
+        data=None,
+        checksum=u'ee36e35a297980dee1b514de9803ec6d'):
+    if data:
+        md5 = hashlib.md5()
+        sha256 = hashlib.sha256()
+        with open(data, 'rb') as file_obj:
+            for chunk in iter(lambda: file_obj.read(8192), b''):
+                md5.update(chunk)
+                sha256.update(chunk)
+        md5 = md5.hexdigest()
+        sha256 = sha256.hexdigest()
     return {
         u'image_state': u'available',
         u'container_format': u'bare',
@@ -242,10 +254,10 @@ def make_fake_image(
         u'min_disk': 40,
         u'virtual_size': None,
         u'name': image_name,
-        u'checksum': u'ee36e35a297980dee1b514de9803ec6d',
+        u'checksum': md5 or checksum,
         u'created_at': u'2016-02-10T05:03:11Z',
-        u'owner_specified.openstack.md5': NO_MD5,
-        u'owner_specified.openstack.sha256': NO_SHA256,
+        u'owner_specified.openstack.md5': md5 or NO_MD5,
+        u'owner_specified.openstack.sha256': sha256 or NO_SHA256,
         u'owner_specified.openstack.object': 'images/{name}'.format(
             name=image_name),
         u'protected': False}
