@@ -31,6 +31,12 @@ class TestBareMetalPort(base.BaseBaremetalTest):
 
         loaded = self.conn.baremetal.get_port(port.id)
         self.assertEqual(loaded.id, port.id)
+        self.assertIsNotNone(loaded.address)
+
+        with_fields = self.conn.baremetal.get_port(port.id,
+                                                   fields=['uuid', 'extra'])
+        self.assertEqual(port.id, with_fields.id)
+        self.assertIsNone(with_fields.address)
 
         self.conn.baremetal.delete_port(port, ignore_missing=False)
         self.assertRaises(exceptions.ResourceNotFound,
@@ -77,6 +83,19 @@ class TestBareMetalPort(base.BaseBaremetalTest):
         self.assertEqual('66:55:44:33:22:11', port.address)
         self.assertEqual({'answer': 42}, port.extra)
 
+    def test_port_patch(self):
+        port = self.create_port(address='11:22:33:44:55:66')
+        port.address = '66:55:44:33:22:11'
+
+        port = self.conn.baremetal.patch_port(
+            port, dict(path='/extra/answer', op='add', value=42))
+        self.assertEqual('66:55:44:33:22:11', port.address)
+        self.assertEqual({'answer': 42}, port.extra)
+
+        port = self.conn.baremetal.get_port(port.id)
+        self.assertEqual('66:55:44:33:22:11', port.address)
+        self.assertEqual({'answer': 42}, port.extra)
+
     def test_port_negative_non_existing(self):
         uuid = "5c9dcd04-2073-49bc-9618-99ae634d8971"
         self.assertRaises(exceptions.ResourceNotFound,
