@@ -21,7 +21,7 @@ import uuid
 
 import mock
 
-from openstack.cloud import openstackcloud
+from openstack import connection
 from openstack.cloud import exc
 from openstack.cloud import meta
 from openstack.tests import fakes
@@ -118,6 +118,7 @@ class TestCreateServer(base.TestCase):
                          u'max_count': 1,
                          u'min_count': 1,
                          u'name': u'server-name'}})),
+            self.get_nova_discovery_mock_dict(),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'compute', 'public', append=['servers', 'detail']),
@@ -157,6 +158,7 @@ class TestCreateServer(base.TestCase):
                          u'max_count': 1,
                          u'min_count': 1,
                          u'name': u'server-name'}})),
+            self.get_nova_discovery_mock_dict(),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'compute', 'public', append=['servers', 'detail']),
@@ -325,7 +327,7 @@ class TestCreateServer(base.TestCase):
 
         self.assert_calls()
 
-    @mock.patch.object(openstackcloud._OpenStackCloudMixin, "wait_for_server")
+    @mock.patch.object(connection.Connection, "wait_for_server")
     def test_create_server_with_admin_pass_wait(self, mock_wait):
         """
         Test that a server with an admin_pass passed returns the password
@@ -411,9 +413,8 @@ class TestCreateServer(base.TestCase):
 
         self.assert_calls()
 
-    @mock.patch.object(
-        openstackcloud._OpenStackCloudMixin, "get_active_server")
-    @mock.patch.object(openstackcloud._OpenStackCloudMixin, "get_server")
+    @mock.patch.object(connection.Connection, "get_active_server")
+    @mock.patch.object(connection.Connection, "get_server")
     def test_wait_for_server(self, mock_get_server, mock_get_active_server):
         """
         Test that waiting for a server returns the server instance when
@@ -447,7 +448,7 @@ class TestCreateServer(base.TestCase):
 
         self.assertEqual('ACTIVE', server['status'])
 
-    @mock.patch.object(openstackcloud._OpenStackCloudMixin, 'wait_for_server')
+    @mock.patch.object(connection.Connection, 'wait_for_server')
     def test_create_server_wait(self, mock_wait):
         """
         Test that create_server with a wait actually does the wait.
@@ -484,8 +485,7 @@ class TestCreateServer(base.TestCase):
         )
         self.assert_calls()
 
-    @mock.patch.object(
-        openstackcloud._OpenStackCloudMixin, 'add_ips_to_server')
+    @mock.patch.object(connection.Connection, 'add_ips_to_server')
     def test_create_server_no_addresses(
             self, mock_add_ips_to_server):
         """
@@ -511,6 +511,7 @@ class TestCreateServer(base.TestCase):
                          u'max_count': 1,
                          u'min_count': 1,
                          u'name': u'server-name'}})),
+            self.get_nova_discovery_mock_dict(),
             dict(method='GET',
                  uri=self.get_mock_url(
                      'compute', 'public', append=['servers', 'detail']),
