@@ -31,12 +31,6 @@ class TestAvailabilityZone(base.TestCase):
         self.assertEqual('/os-availability-zone', sot.base_path)
         self.assertTrue(sot.allow_list)
 
-    def test_basic_detail(self):
-        sot = az.AvailabilityZoneDetail()
-        self.assertEqual('availabilityZoneInfo', sot.resources_key)
-        self.assertEqual('/os-availability-zone/detail', sot.base_path)
-        self.assertTrue(sot.allow_list)
-
     def test_make_basic(self):
         sot = az.AvailabilityZone(**BASIC_EXAMPLE)
         self.assertEqual(BASIC_EXAMPLE['id'], sot.id)
