@@ -177,7 +177,7 @@ class TestProxyBase(base.TestCase):
                     mock_method="openstack.proxy.Proxy._find",
                     path_args=None, **kwargs):
         method_args = value or ["name_or_id"]
-        expected_kwargs = {}
+        expected_kwargs = kwargs.pop('expected_kwargs', {})
 
         self._add_path_args_for_verify(path_args, method_args, expected_kwargs,
                                        value=value)
@@ -207,6 +207,7 @@ class TestProxyBase(base.TestCase):
         if 'paginated' in kwargs:
             expected_kwargs.update({"paginated": kwargs.pop('paginated')})
         method_kwargs = kwargs.pop("method_kwargs", {})
+        expected_kwargs["base_path"] = kwargs.pop("base_path", None)
         self._verify2(mock_method, test_method,
                       method_kwargs=method_kwargs,
                       expected_args=[resource_type],
